@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include <math.h>
+#include "backend.h"
 
 using namespace Rcpp;
 
@@ -318,7 +319,7 @@ NumericMatrix linRcpp(NumericMatrix & rho,
 
       // Calculate Z and variance of Z
       double var_ij = (1 - pow(r(i, j), 2)) * pow(rho(i, j), 2) /
-        (1 - pow(rho(i, j), 2)) / pow(r(i, j), 2) / (N - 2);
+      (1 - pow(rho(i, j), 2)) / pow(r(i, j), 2) / (N - 2);
       double z_ij = atanh(rho(i, j));
 
       // Replace r with Z and var
@@ -405,23 +406,3 @@ NumericMatrix rhoToPhs(NumericMatrix & X){
 
   return X;
 }
-
-/*** R
-X <- t(data.frame("a" = sample(1:10), "b" = sample(1:10), "c" = sample(1:10),
-                  "d" = sample(1:10), "e" = sample(1:10), "f" = sample(1:10)))
-
-if(!all(round(cor(X) - corRcpp(X), 5) == 0)) stop("corRcpp error!")
-if(!all(round(cov(X) - covRcpp(X), 5) == 0)) stop("covRcpp error!")
-
-if(!all(round(propr:::proprVLR(X) - vlrRcpp(X), 5) == 0)) stop("vlrRcpp error!")
-if(!all(round(propr:::proprCLR(X) - clrRcpp(X), 5) == 0)) stop("clrRcpp error!")
-if(!all(round(propr:::proprALR(X, ivar = 5) - alrRcpp(X, ivar = 5)[, -5], 5) == 0)) stop("alrRcpp error!")
-if(!all((propr:::proprSym(X) - symRcpp(X)) == 0)) stop("symRcpp error!")
-
-if(!all(round(propr:::proprPhit(X) - phiRcpp(X), 5) == 0)) stop("phiRcpp error!")
-if(!all(round(propr:::proprPerb(X) - rhoRcpp(X, propr:::proprCLR(X)), 5) == 0)) stop("rhoRcpp error!")
-if(!all(propr:::proprTri(X) - X[indexPairs(X, "all")] == 0)) stop("indexPairs error!")
-
-X <- t(data.frame("a" = sample(-5:10), "b" = sample(-5:10), "c" = sample(-5:10),
-                  "d" = sample(-5:10), "e" = sample(-5:10), "f" = sample(-5:10)))
-*/
